#
class ai4ca (
  String $www_root = '/usr/share/nginx/html',
  Array[String] $index_files = ['index.html'],
) {
  include profiles::letsencrypt
  include nginx
  include liurepo::postgres

  yumrepo { 'pgdg-common':
    name     => 'pgdg-common',
    baseurl  => 'https://download.postgresql.org/pub/repos/yum/common/redhat/rhel-$releasever-$basearch',
    enabled  => 1,
    gpgkey   => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-PGDG',
    gpgcheck => 1,
    require  => Class['liurepo::postgres'],
  }

  package { 'postgresql':
    ensure   => disabled,
    provider => 'dnfmodule',
  }

  package {
    [
      'postgresql11-server',
      'postgis31_11',
      'python3',
    ]:
      ensure => installed,
  }

  if fact("letsencrypt_certs.\"${fact('networking.fqdn')}\".files.combined") {
    nginx::resource::server { fact('networking.fqdn'):
      ensure              => present,
      www_root            => $www_root,
      location_cfg_append => {
        'rewrite' => '^ https://$server_name$request_uri? permanent',
      },
    }

    nginx::resource::server { "${fact('networking.fqdn')} HTTPS":
      ensure        => present,
      listen_port   => 443,
      www_root      => $www_root,
      index_files   => $index_files,
      ssl           => true,
      ssl_cert      => fact("letsencrypt_certs.\"${fact('networking.fqdn')}\".files.combined"),
      ssl_key       => fact("letsencrypt_certs.\"${fact('networking.fqdn')}\".files.key"),
      ssl_protocols => 'TLSv1.3 TLSv1.2',
      ssl_ciphers   => 'ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES256-GCM-SHA384:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-CHACHA20-POLY1305:ECDHE-RSA-CHACHA20-POLY1305:DHE-RSA-AES128-GCM-SHA256:DHE-RSA-AES256-GCM-SHA384', # lint:ignore:140chars
    }

    nginx::resource::location { '/va':
      ensure   => present,
      ssl      => true,
      ssl_only => true,
      server   => "${fact('networking.fqdn')} HTTPS",
      proxy    => 'http://localhost:8100/',
    }
  }

  firewalld_service {
    'nginx http LiU':
      zone    => 'liu',
      service => 'http';
    'nginx https LiU':
      zone    => 'liu',
      service => 'https';
    'nginx http Public':
      zone    => 'public',
      service => 'http';
    'nginx https Public':
      zone    => 'public',
      service => 'https';
  }
}
